==> webkit2gtk_2.50.0.orig.tar.xz: webkitgtk-2.50.0/Source/WebCore/Modules/mediastream/RTCRtpSenderBackend.h <==
/*
 * Copyright (C) 2018 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1.  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 * 2.  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(WEB_RTC)

#include <wtf/FixedVector.h>
#include <wtf/Forward.h>

namespace WebCore {

class MediaStreamTrack;
class RTCDTMFSenderBackend;
class RTCDtlsTransportBackend;
class RTCRtpSender;
class RTCRtpTransformBackend;
class ScriptExecutionContext;

struct RTCRtpSendParameters;

template<typename IDLType> class DOMPromiseDeferred;

class RTCRtpSenderBackend {
public:
    virtual ~RTCRtpSenderBackend() = default;

    virtual bool replaceTrack(RTCRtpSender&, MediaStreamTrack*) = 0;
    virtual RTCRtpSendParameters getParameters() const = 0;
    virtual void setParameters(const RTCRtpSendParameters&, DOMPromiseDeferred<void>&&) = 0;
    virtual std::unique_ptr<RTCDTMFSenderBackend> createDTMFBackend() = 0;
    virtual Ref<RTCRtpTransformBackend> rtcRtpTransformBackend() = 0;
    virtual void setMediaStreamIds(const FixedVector<String>&) = 0;
    virtual std::unique_ptr<RTCDtlsTransportBackend> dtlsTransportBackend() = 0;
};

} // namespace WebCore

#endif // ENABLE(WEB_RTC)

==> webkit2gtk_2.51.3.orig.tar.xz: webkitgtk-2.51.3/Source/WebCore/Modules/mediastream/RTCRtpSenderBackend.h <==
/*
 * Copyright (C) 2018 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1.  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 * 2.  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(WEB_RTC)

#include <wtf/AbstractRefCounted.h>
#include <wtf/FixedVector.h>
#include <wtf/Forward.h>

namespace WebCore {

class MediaStreamTrack;
class RTCDTMFSenderBackend;
class RTCDtlsTransportBackend;
class RTCRtpSender;
class RTCRtpTransformBackend;
class ScriptExecutionContext;

struct RTCRtpSendParameters;

template<typename IDLType> class DOMPromiseDeferred;

class RTCRtpSenderBackend : public AbstractRefCounted {
public:
    virtual ~RTCRtpSenderBackend() = default;

    virtual bool replaceTrack(RTCRtpSender&, MediaStreamTrack*) = 0;
    virtual RTCRtpSendParameters getParameters() const = 0;
    virtual void setParameters(const RTCRtpSendParameters&, DOMPromiseDeferred<void>&&) = 0;
    virtual std::unique_ptr<RTCDTMFSenderBackend> createDTMFBackend() = 0;
    virtual Ref<RTCRtpTransformBackend> rtcRtpTransformBackend() = 0;
    virtual void setMediaStreamIds(const FixedVector<String>&) = 0;
    virtual std::unique_ptr<RTCDtlsTransportBackend> dtlsTransportBackend() = 0;
};

} // namespace WebCore

#endif // ENABLE(WEB_RTC)
